import React, { useEffect, useRef, useCallback, useState } from 'react';
import { WebView } from 'react-native-webview';
import DeviceInfo from 'react-native-device-info';
import { generateRestaurantURL } from './utils/uri';
import NativeService from './services/NativeService';
import { StyleSheet, View } from 'react-native';
import LoadingService from './services/LoadingService';
import LeaveService from './services/LeaveService';
var userAgent = DeviceInfo.getUserAgent() + " - UEAT Native App - " + DeviceInfo.getBundleId() + " - " + DeviceInfo.getVersion();
function UEATRestaurant(_a) {
    var apiKey = _a.apiKey, culture = _a.culture, isMarketplace = _a.isMarketplace, renderError = _a.renderError, renderLoading = _a.renderLoading, onLeave = _a.onLeave;
    var _b = useState(true), loading = _b[0], setLoading = _b[1];
    var _c = useState(false), error = _c[0], setError = _c[1];
    var webviewRef = useRef();
    var nativeServiceRef = useRef(new NativeService());
    var setWebviewRef = useCallback(function (ref) {
        webviewRef.current = ref;
        nativeServiceRef.current.webview = webviewRef.current;
    }, []);
    useEffect(function () {
        LoadingService.updateCallback(setLoading);
    }, []);
    useEffect(function () {
        LeaveService.updateCallback(onLeave);
    }, [onLeave]);
    var retry = useCallback(function () {
        setLoading(true);
        setError(false);
        webviewRef.current.reload();
    }, []);
    var onErrorInner = useCallback(function () {
        setError(true);
        setLoading(false);
    }, []);
    var onMessageInner = useCallback(function (e) {
        nativeServiceRef.current.onMessage(e, {
            apiKey: apiKey,
            culture: culture,
            isMarketplace: isMarketplace
        });
    }, [nativeServiceRef.current, apiKey, culture]);
    var uri = generateRestaurantURL({ apiKey: apiKey, culture: culture, isMarketplace: isMarketplace });
    return (React.createElement(View, { style: styles.container },
        React.createElement(WebView, { userAgent: userAgent, bounces: false, originWhitelist: ['*'], source: { uri: uri }, renderError: function () { return React.createElement(React.Fragment, null); }, renderLoading: function () { return React.createElement(React.Fragment, null); }, onError: onErrorInner, onMessage: onMessageInner, ref: setWebviewRef }),
        loading && !!renderLoading && (React.createElement(View, { style: styles.spinner }, renderLoading)),
        error && !!renderError && (React.createElement(View, { style: styles.spinner }, renderError(retry)))));
}
UEATRestaurant.defaultProps = {
    isMarketplace: false
};
var styles = StyleSheet.create({
    container: {
        flex: 1
    },
    spinner: {
        position: 'absolute',
        top: 0,
        left: 0,
        right: 0,
        bottom: 0,
        justifyContent: 'center',
        alignItems: 'center'
    }
});
export default UEATRestaurant;
